@@ -353,6 +353,15 @@ render_close_img_span(MD_RENDER_HTML* r, const MD_SPAN_IMG_DETAIL* det)
     r->image_nesting_level--;
 }
 
+static void
+render_open_wikilink_span(MD_RENDER_HTML* r, const MD_SPAN_WIKILINK_DETAIL* det)
+{
+    RENDER_LITERAL(r, "<x-wikilink data-target=\"");
+    render_attribute(r, &det->target, render_html_escaped);
+
+    RENDER_LITERAL(r, "\">");
+}
+
 
 /**************************************
  ***  HTML renderer implementation  ***
@@ -426,12 +435,15 @@ enter_span_callback(MD_SPANTYPE type, void* detail, void* userdata)
     }
 
     switch(type) {
-        case MD_SPAN_EM:        RENDER_LITERAL(r, "<em>"); break;
-        case MD_SPAN_STRONG:    RENDER_LITERAL(r, "<strong>"); break;
-        case MD_SPAN_A:         render_open_a_span(r, (MD_SPAN_A_DETAIL*) detail); break;
-        case MD_SPAN_IMG:       render_open_img_span(r, (MD_SPAN_IMG_DETAIL*) detail); break;
-        case MD_SPAN_CODE:      RENDER_LITERAL(r, "<code>"); break;
-        case MD_SPAN_DEL:       RENDER_LITERAL(r, "<del>"); break;
+        case MD_SPAN_EM:                RENDER_LITERAL(r, "<em>"); break;
+        case MD_SPAN_STRONG:            RENDER_LITERAL(r, "<strong>"); break;
+        case MD_SPAN_A:                 render_open_a_span(r, (MD_SPAN_A_DETAIL*) detail); break;
+        case MD_SPAN_IMG:               render_open_img_span(r, (MD_SPAN_IMG_DETAIL*) detail); break;
+        case MD_SPAN_CODE:              RENDER_LITERAL(r, "<code>"); break;
+        case MD_SPAN_DEL:               RENDER_LITERAL(r, "<del>"); break;
+        case MD_SPAN_LATEXMATH:         RENDER_LITERAL(r, "<x-equation>"); break;
+        case MD_SPAN_LATEXMATH_DISPLAY: RENDER_LITERAL(r, "<x-equation type=\"display\">"); break;
+        case MD_SPAN_WIKILINK:          render_open_wikilink_span(r, (MD_SPAN_WIKILINK_DETAIL*) detail); break;
     }
 
     return 0;
@@ -451,12 +463,15 @@ leave_span_callback(MD_SPANTYPE type, void* detail, void* userdata)
     }
 
     switch(type) {
-        case MD_SPAN_EM:        RENDER_LITERAL(r, "</em>"); break;
-        case MD_SPAN_STRONG:    RENDER_LITERAL(r, "</strong>"); break;
-        case MD_SPAN_A:         RENDER_LITERAL(r, "</a>"); break;
-        case MD_SPAN_IMG:       /*noop, handled above*/ break;
-        case MD_SPAN_CODE:      RENDER_LITERAL(r, "</code>"); break;
-        case MD_SPAN_DEL:       RENDER_LITERAL(r, "</del>"); break;
+        case MD_SPAN_EM:                RENDER_LITERAL(r, "</em>"); break;
+        case MD_SPAN_STRONG:            RENDER_LITERAL(r, "</strong>"); break;
+        case MD_SPAN_A:                 RENDER_LITERAL(r, "</a>"); break;
+        case MD_SPAN_IMG:               /*noop, handled above*/ break;
+        case MD_SPAN_CODE:              RENDER_LITERAL(r, "</code>"); break;
+        case MD_SPAN_DEL:               RENDER_LITERAL(r, "</del>"); break;
+        case MD_SPAN_LATEXMATH:         /*fall through*/
+        case MD_SPAN_LATEXMATH_DISPLAY: RENDER_LITERAL(r, "</x-equation>"); break;
+        case MD_SPAN_WIKILINK:          RENDER_LITERAL(r, "</x-wikilink>"); break;
     }
 
     return 0;
